pub struct PinRef { /* private fields */ }Expand description
A reference to a component pin, such as U2:VCC or R1:1.
Implementations
Sourceimpl PinRef
impl PinRef
Sourcepub const fn new(component: ReferenceDesignator, pin: PinIdentifier) -> Self
pub const fn new(component: ReferenceDesignator, pin: PinIdentifier) -> Self
Creates a pin reference from a component designator and pin identifier.
Sourcepub const fn numbered(component: ReferenceDesignator, pin: PinNumber) -> Self
pub const fn numbered(component: ReferenceDesignator, pin: PinNumber) -> Self
Creates a pin reference from a numeric pin.
Sourcepub const fn named(component: ReferenceDesignator, pin: PinName) -> Self
pub const fn named(component: ReferenceDesignator, pin: PinName) -> Self
Creates a pin reference from a named pin.
Sourcepub const fn component(&self) -> &ReferenceDesignator
pub const fn component(&self) -> &ReferenceDesignator
Returns the component reference designator.
Sourcepub const fn pin(&self) -> &PinIdentifier
pub const fn pin(&self) -> &PinIdentifier
Returns the pin identifier.